/*
 * Copyright 2020 Ladifire. All rights reserved.
 * This file is licensed to you under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License. You may obtain a copy
 * of the License at http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under
 * the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR REPRESENTATIONS
 * OF ANY KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */

import AlertMedium from '@spectrum-icons/ui/AlertMedium';
import {Button} from '@ladifire-ui-react/button';
import {ButtonGroup} from '@ladifire-ui-react/buttongroup';
import {chain} from '@react-ui-aria/utils';
import {classNames, useStyleProps} from '@ladifire-ui-react/utils';
import {Content} from '@ladifire-ui-react/view';
import {Dialog} from './Dialog';
import {DialogContext, DialogContextValue} from './context';
import {Divider} from '@ladifire-ui-react/divider';
import {DOMRef} from '@react-ui-types/shared';
import {Heading} from '@ladifire-ui-react/text';
import * as React from 'react';
import {SpectrumAlertDialogProps} from '@react-ui-types/dialog';
import {SpectrumButtonProps} from '@react-ui-types/button';
import styles from '@adobe/spectrum-css-temp/components/dialog/vars.css';

/**
 * AlertDialogs are a specific type of Dialog. They display important information that users need to acknowledge.
 */
function AlertDialog(props: SpectrumAlertDialogProps, ref: DOMRef) {
  let {
    onClose = () => {}
  } = React.useContext(DialogContext) || {} as DialogContextValue;

  let {
    variant,
    children,
    primaryActionLabel,
    secondaryActionLabel,
    cancelLabel,
    autoFocusButton,
    title,
    isPrimaryActionDisabled,
    isSecondaryActionDisabled,
    onCancel = () => {},
    onPrimaryAction = () => {},
    onSecondaryAction = () => {},
    ...otherProps
  } = props;
  let {styleProps} = useStyleProps(otherProps);

  let confirmVariant: SpectrumButtonProps['variant'] = 'primary';
  if (variant) {
    if (variant === 'confirmation') {
      confirmVariant = 'cta';
    } else if (variant === 'destructive') {
      confirmVariant = 'negative';
    }
  }

  return (
    <Dialog
      UNSAFE_style={styleProps.style}
      UNSAFE_className={classNames(styles, {[`spectrum-Dialog--${variant}`]: variant}, styleProps.className)}
      isHidden={styleProps.hidden}
      size="M"
      role="alertdialog"
      ref={ref}>
      <Heading>{title}</Heading>
      {(variant === 'error' || variant === 'warning') &&
      <AlertMedium
        slot="typeIcon"
        aria-label='alert' />
      }
      <Divider />
      <Content>{children}</Content>
      <ButtonGroup align="end">
        {cancelLabel &&
        <Button
          variant="secondary"
          onPress={() => chain(onClose(), onCancel())}
          autoFocus={autoFocusButton === 'cancel'}>
          {cancelLabel}
        </Button>
        }
        {secondaryActionLabel &&
        <Button
          variant="secondary"
          onPress={() => chain(onClose(), onSecondaryAction())}
          isDisabled={isSecondaryActionDisabled}
          autoFocus={autoFocusButton === 'secondary'}>
          {secondaryActionLabel}
        </Button>
        }
        <Button
          variant={confirmVariant}
          onPress={() => chain(onClose(), onPrimaryAction())}
          isDisabled={isPrimaryActionDisabled}
          autoFocus={autoFocusButton === 'primary'}>
          {primaryActionLabel}
        </Button>
      </ButtonGroup>
    </Dialog>
  );
}

/**
 * AlertDialogs are a specific type of Dialog. They display important information that users need to acknowledge.
 */
let _AlertDialog = React.forwardRef(AlertDialog);
export {_AlertDialog as AlertDialog};
